# Brainstorm Search


## Purpose
To summarize idea lists from Duckduckgo search to make brainstorming ideas and idea research more efficient

## Installation
```
pip install brainstorm-search
```

## Usage
```
brainstorm <list related search term>
```
### Examples
```
brainstorm "best flavors of icecream"
brainstorm "top 10 vacation destinations"
brainstorm "most popular american presidents"
```
